@@ -34,6 +34,7 @@ from pygments.util import ClassNotFound
 
 from pyquery import PyQuery as pq
 from requests.exceptions import ConnectionError
+from requests.exceptions import SSLError
 
 # Handle unicode between Python 2 and 3
 # http://stackoverflow.com/a/6633040/305414
@@ -45,18 +46,32 @@ else:
     def u(x):
         return x
 
-SEARCH_URL = 'https://www.google.com/search?q=site:stackoverflow.com%20{0}'
+
+if os.getenv('HOWDOI_DISABLE_SSL'):  # Set http instead of https
+    SEARCH_URL = 'http://www.google.com/search?q=site:stackoverflow.com%20{0}'
+else:
+    SEARCH_URL = 'https://www.google.com/search?q=site:stackoverflow.com%20{0}'
+
+
 USER_AGENTS = ('Mozilla/5.0 (Macintosh; Intel Mac OS X 10.7; rv:11.0) Gecko/20100101 Firefox/11.0',
+               'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:22.0) Gecko/20100 101 Firefox/22.0'
                'Mozilla/5.0 (Windows NT 6.1; rv:11.0) Gecko/20100101 Firefox/11.0',
                'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_7_4) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.46 Safari/536.5',
                'Mozilla/5.0 (Windows; Windows NT 6.1) AppleWebKit/536.5 (KHTML, like Gecko) Chrome/19.0.1084.46 Safari/536.5',)
 ANSWER_HEADER = u('--- Answer {0} ---\n{1}')
 NO_ANSWER_MSG = '< no answer given >'
 CACHE_DIR = os.path.join(os.path.expanduser('~'), '.howdoi')
-CACHE_FILE = os.path.join(CACHE_DIR, 'cache')
+CACHE_FILE = os.path.join(CACHE_DIR, 'cache{0}'.format(
+        sys.version_info[0] if sys.version_info[0] == '3' else ''))
+
 
 def get_result(url):
-    return requests.get(url, headers={'User-Agent': random.choice(USER_AGENTS)}, proxies=get_proxies()).text
+    try:
+        return requests.get(url, headers={'User-Agent': random.choice(USER_AGENTS)}, proxies=get_proxies()).text
+    except requests.exceptions.SSLError as e:
+        print('[ERROR] Encountered an SSL Error. Try using HTTP instead of '
+              'HTTPS by setting the environment variable "HOWDOI_DISABLE_SSL".\n')
+        raise e
 
 
 def is_question(link):
@@ -64,21 +79,19 @@ def is_question(link):
 
 
 def get_links(query):
-    url = SEARCH_URL.format(url_quote(query))
-    result = get_result(url)
+    result = get_result(SEARCH_URL.format(url_quote(query)))
     html = pq(result)
     return [a.attrib['href'] for a in html('.l')] or \
         [a.attrib['href'] for a in html('.r')('a')]
 
 
-def get_link_at_pos(links, pos):
-    for link in links:
-        if is_question(link):
-            if pos == 1:
-                break
-            else:
-                pos = pos - 1
-                continue
+def get_link_at_pos(links, position):
+    links = [link for link in links if is_question(link)]
+
+    if len(links) >= position:
+        link = links[position-1]
+    else:
+        link = links[-1]
     return link
 
 
@@ -100,11 +113,9 @@ def format_output(code, args):
     if not lexer:
         lexer = guess_lexer(code)
 
-    return highlight(
-        code,
-        lexer,
-        TerminalFormatter(bg='dark')
-    )
+    return highlight(code,
+                     lexer,
+                     TerminalFormatter(bg='dark'))
 
 
 def get_answer(args, links):
@@ -174,7 +185,7 @@ def howdoi(args):
     args['query'] = ' '.join(args['query']).replace('?', '')
     try:
         return get_instructions(args) or 'Sorry, couldn\'t find any help with that topic\n'
-    except ConnectionError:
+    except (ConnectionError, SSLError):
         return 'Failed to establish network connection\n'
 
 
@@ -192,7 +203,6 @@ def get_parser():
     parser.add_argument('-n','--num-answers', help='number of answers to return', default=1, type=int)
     parser.add_argument('-C','--clear-cache', help='clear the cache',
                         action='store_true')
-
     return parser
 
 
@@ -213,9 +223,9 @@ def command_line_runner():
     if not os.getenv('HOWDOI_DISABLE_CACHE'):
         enable_cache()
 
-
     print(howdoi(args).encode('utf-8', 'ignore'))
 
 
+
 if __name__ == '__main__':
     command_line_runner()
